package com.ruoyi.care.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.care.mapper.CareNurseClocksMapper;
import com.ruoyi.care.domain.CareNurseClocks;
import com.ruoyi.care.service.ICareNurseClocksService;

/**
 * 护理任务打卡Service业务层处理
 * 
 * @author qy
 * @date 2024-11-26
 */
@Service
public class CareNurseClocksServiceImpl implements ICareNurseClocksService 
{
    @Autowired
    private CareNurseClocksMapper careNurseClocksMapper;

    /**
     * 查询护理任务打卡
     * 
     * @param clockId 护理任务打卡主键
     * @return 护理任务打卡
     */
    @Override
    public CareNurseClocks selectCareNurseClocksByClockId(Long clockId)
    {
        return careNurseClocksMapper.selectCareNurseClocksByClockId(clockId);
    }

    /**
     * 查询护理任务打卡列表
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 护理任务打卡
     */
    @Override
    public List<CareNurseClocks> selectCareNurseClocksList(CareNurseClocks careNurseClocks)
    {
        return careNurseClocksMapper.selectCareNurseClocksList(careNurseClocks);
    }

    /**
     * 新增护理任务打卡
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 结果
     */
    @Override
    public int insertCareNurseClocks(CareNurseClocks careNurseClocks)
    {
        careNurseClocks.setCreateTime(DateUtils.getNowDate());
        return careNurseClocksMapper.insertCareNurseClocks(careNurseClocks);
    }

    /**
     * 修改护理任务打卡
     * 
     * @param careNurseClocks 护理任务打卡
     * @return 结果
     */
    @Override
    public int updateCareNurseClocks(CareNurseClocks careNurseClocks)
    {
        careNurseClocks.setUpdateTime(DateUtils.getNowDate());
        return careNurseClocksMapper.updateCareNurseClocks(careNurseClocks);
    }

    /**
     * 批量删除护理任务打卡
     * 
     * @param clockIds 需要删除的护理任务打卡主键
     * @return 结果
     */
    @Override
    public int deleteCareNurseClocksByClockIds(Long[] clockIds)
    {
        return careNurseClocksMapper.deleteCareNurseClocksByClockIds(clockIds);
    }

    /**
     * 删除护理任务打卡信息
     * 
     * @param clockId 护理任务打卡主键
     * @return 结果
     */
    @Override
    public int deleteCareNurseClocksByClockId(Long clockId)
    {
        return careNurseClocksMapper.deleteCareNurseClocksByClockId(clockId);
    }
}
